@@ -95,7 +95,7 @@ def select_all(
     :return: iterable ResultProxy object that stores results of the select query
     """
     engine = get_db_engine(username, password, host, db_name)
-    conn = engine.raw_connection()
+    connection = engine.raw_connection()
     if where_statement_params is None:
         where_statement_params = dict()
     where_statement = read_sql(sql_file=where_statement_file, **where_statement_params)
@@ -103,9 +103,11 @@ def select_all(
         table_name=table_name,
         where_statement=where_statement,
     )
-    result = conn.execute(sql).fetch_all()
-    conn.commit()
-    conn.close()
-    logger.LOGGER("The below sql statement is executed" + sql)
+    cursor = connection.cursor()
+    cursor.execute(sql)
+    result = cursor.fetchall()
+    connection.commit()
+    connection.close()
+    logger.LOGGER("The below sql statement is executed \n" + sql)
     logger.LOGGER("Number of records retrieved = " + str(len(result)))
     return result
